{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/do_cle_vcf_filter"
                },
                {
                    "type": "float",
                    "id": "#main/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": "float",
                    "id": "#main/filter_mapq0_threshold"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/tumor_bam"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_vcf_cle.cwl",
                    "in": [
                        {
                            "source": "#main/do_cle_vcf_filter",
                            "id": "#main/filter_vcf_cle/filter"
                        },
                        {
                            "source": "#main/filter_vcf_mapq0/mapq0_filtered_vcf",
                            "id": "#main/filter_vcf_cle/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_cle/cle_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_cle"
                },
                {
                    "run": "#filter_vcf_gnomADe_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#main/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#main/filter_vcf_gnomADe_allele_freq/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/filter_vcf_gnomADe_allele_freq/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_gnomADe_allele_freq/filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_gnomADe_allele_freq"
                },
                {
                    "run": "#filter_vcf_mapq0.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_vcf_mapq0/reference"
                        },
                        {
                            "source": "#main/filter_mapq0_threshold",
                            "id": "#main/filter_vcf_mapq0/threshold"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/filter_vcf_mapq0/tumor_bam"
                        },
                        {
                            "source": "#main/filter_vcf_gnomADe_allele_freq/filtered_vcf",
                            "id": "#main/filter_vcf_mapq0/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_mapq0/mapq0_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_mapq0"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filter_vcf_cle/cle_filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "cle_annotated_vcf_filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/docm_and_coding_indel_selection.pl",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "filter",
                        "position": 1
                    },
                    "id": "#filter_vcf_cle.cwl/filter"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf_cle.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated_filtered.vcf"
                    },
                    "id": "#filter_vcf_cle.cwl/cle_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_cle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "gnomADe_AF filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            \"gnomADe_AF\", \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", \"gnomADe_AF\"\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_gnomADe_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_gnomADe_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter_vcf for variants with high percentage of mapq0 reads",
            "arguments": [
                "/bin/bash",
                "/usr/bin/mapq0_vcf_filter.sh",
                {
                    "valueFrom": "$(runtime.outdir)/mapq_filtered.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter_vcf_mapq0.cwl/reference"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter_vcf_mapq0.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf_mapq0.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter_vcf_mapq0.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_filtered.vcf.gz"
                    },
                    "id": "#filter_vcf_mapq0.cwl/mapq0_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_mapq0.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
